#!/bin/sh

systemctl stop vgserver
systemctl disable vgserver

rm /etc/systemd/system/vgserver.service

rm -rf /opt/VideoGrace/Server/bin
rm -rf /opt/VideoGrace/Server/img
rm -rf /opt/VideoGrace/Server/js
rm -rf /opt/VideoGrace/Server/locale
rm -rf /opt/VideoGrace/Server/template
rm /opt/VideoGrace/Server/VideoGraceServer
rm /opt/VideoGrace/Server/Consolidator
rm /opt/VideoGrace/Server/Recorder
rm -rf /var/log/vgserver

echo "\033[1m\033[32mVideoGrace Server has been stopped and deleted.\nOur database are saved on /opt/VideoGrace/Server/db\033[m"
echo "We hope to see you again at: \033[1m\033[36mhttps://videograce.com\033[m \033[1m\033[31m❤️\033[m"
